package com.diagbot.repository;


import com.diagbot.dto.BillNeoDTO;
import com.diagbot.dto.HighRiskNeoDTO;
import com.diagbot.dto.OperationBillNeoDTO;
import com.diagbot.dto.OperationInfoDTO;
import com.diagbot.entity.node.*;
import com.diagbot.util.NeoUtil;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.Set;

public class OperationNode {


    public OperationBillNeoDTO OperationtoOperationDTO(Operation operation) {
        OperationBillNeoDTO opBillNeoDTO = new OperationBillNeoDTO();


        Gender gender = operation.getGender();
        if (null!=gender) {
            opBillNeoDTO.setGender(NeoUtil.updateNodeInfo(gender.getName(), null, null, null, null));
        }

        Set<ClinicalFinding> clinicalfindings = operation.getClinicalFindings();
        for (ClinicalFinding clinicalfinding : clinicalfindings) {
            String name = clinicalfinding.getName();
            BigDecimal min = NeoUtil.DoubletoBigDecimal(clinicalfinding.getMinval());
            BigDecimal max = NeoUtil.DoubletoBigDecimal(clinicalfinding.getMaxval());
            String unit = clinicalfinding.getUnit();
            Integer range = clinicalfinding.getRange();
            opBillNeoDTO.getClinicfindings().add(NeoUtil.updateNodeInfo(name, min, max, unit, range));
        }

        Set<Vital> vitals = operation.getVitals();
        for (Vital vital : vitals) {
            String name = vital.getName();
            BigDecimal min = NeoUtil.DoubletoBigDecimal(vital.getMinval());
            BigDecimal max = NeoUtil.DoubletoBigDecimal(vital.getMaxval());
            String unit = vital.getUnit();
            Integer range = vital.getRange();
            opBillNeoDTO.getVitals().add(NeoUtil.updateNodeInfo(name, min, max, unit, range));
        }

        Set<LIS> lisSet = operation.getConflict_lis();
        for (LIS lis : lisSet) {
            String name = lis.getName();
            BigDecimal min = NeoUtil.DoubletoBigDecimal(lis.getMinval());
            BigDecimal max = NeoUtil.DoubletoBigDecimal(lis.getMaxval());
            String unit = lis.getUnit();
            Integer range = lis.getRange();
            opBillNeoDTO.getLis().add(NeoUtil.updateNodeInfo(name, min, max, unit, range));
        }

        Set<OralMedicine> conflict_oralmeds = operation.getOralMedicines();
        for (OralMedicine conflict_oralmed : conflict_oralmeds) {
            String name = conflict_oralmed.getName();
            opBillNeoDTO.getConflictmeds().add(NeoUtil.updateNodeInfo(name, null, null, null, null));
        }

        Set<Disease> conflict_disease = operation.getDiseases();
        for (Disease disease : conflict_disease) {
            String name = disease.getName();
            opBillNeoDTO.getDisease().add(NeoUtil.updateNodeInfo(name, null, null, null, null));
        }

        Set<Group> conflict_group = operation.getGroups();
        for (Group group : conflict_group) {
            String name = group.getName();
            opBillNeoDTO.getGroup().add(NeoUtil.updateNodeInfo(name, null, null, null, null));
        }

        return opBillNeoDTO;
    }

    /**
     * 处理手术开单合理性
     */
    public List<BillNeoDTO> getOperationBill(Map<String, String> opterm, OperationRepository opRepository) {
        List<BillNeoDTO> billNeoDTOs = new ArrayList<>();
        BillNeoDTO billNeoDTO;

        OperationBillNeoDTO opBillNeoDTO;

        String opname;

        for (String term : opterm.keySet()) {
            billNeoDTO = new BillNeoDTO();
            opname = opterm.get(term);
            billNeoDTO.setName(opname);

            List<Operation> operations = opRepository.findByNameIs(opname);

            if (null!=operations && operations.size()>0) {
                opBillNeoDTO = OperationtoOperationDTO(operations.get(0));
                billNeoDTO.setOperationBillNeoDTO(opBillNeoDTO);
            }

            billNeoDTOs.add(billNeoDTO);
        }

        return billNeoDTOs;
    }

    /**
     * 获取手术操作名称列表
     */
    public List<OperationInfoDTO> getOperationList(String name, OperationRepository operationRepository) {
        String nodename;

        List<OperationInfoDTO> opslist = new ArrayList<>();
        OperationInfoDTO opInfoDTO;

        List<Operation> operations = operationRepository.findByNameLike("*"+name+"*");

        for (Operation op : operations) {
            opInfoDTO = new OperationInfoDTO();
            nodename = op.getName();

            opInfoDTO.setName(nodename);
            opslist.add(opInfoDTO);
        }


        return opslist;
    }



    /**
     * 获取高危手术和操作数据
     */
    public List<HighRiskNeoDTO> getHighRiskOperation(Map<String, String> opsterm, OperationRepository operationRepository) {
        List<HighRiskNeoDTO> highRiskNeoDTOS = new ArrayList<>();
        HighRiskNeoDTO highRiskNeoDTO;
        String opname;
        Operation operation;

        for (String term : opsterm.keySet()) {
            highRiskNeoDTO = new HighRiskNeoDTO();

            opname = opsterm.get(term);
            highRiskNeoDTO.setName(term);
            highRiskNeoDTO.setStandname(opname);

            List<Operation> operations = operationRepository.findByNameIs(opname);

            if (null != operations) {
                operation = operations.get(0);
                if (null!=operation.getRisklevel() && operation.getRisklevel().trim().length()>0) {
                    highRiskNeoDTO.setIsHighrisk(true);
                    highRiskNeoDTO.setType("手术");
                    highRiskNeoDTOS.add(highRiskNeoDTO);
                }
            }
        }

        return highRiskNeoDTOS;
    }

}
